@@ -20,7 +20,6 @@ const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
 const Lang = imports.lang;
 const GWeather = imports.gi.GWeather;
-const Geocode = imports.gi.GeocodeGlib;
 
 const Util = imports.misc.util;
 
@@ -81,17 +80,27 @@ const CurrentLocationController = new Lang.Class({
 
     _startGeolocationService: function() {
         this._processStarted = true;
-        this._managerProxy = new ManagerProxy(Gio.DBus.system,
-                                              "org.freedesktop.GeoClue2",
-                                              "/org/freedesktop/GeoClue2/Manager");
+        try {
+            this._managerProxy = new ManagerProxy(Gio.DBus.system,
+                                                  "org.freedesktop.GeoClue2",
+                                                  "/org/freedesktop/GeoClue2/Manager");
 
-        this._managerProxy.GetClientRemote(this._onGetClientReady.bind(this));
+            this._managerProxy.GetClientRemote(this._onGetClientReady.bind(this));
+        } catch(e) {
+            this._geoLocationFailed(e);
+        }
+    },
+
+    _geoLocationFailed: function(e) {
+        log ("Failed to connect to GeoClue2 service: " + e.message);
+        GLib.idle_add(GLib.PRIORITY_DEFAULT, Lang.bind(this, function() {
+            this._world.currentLocationChanged(null);
+        }));
     },
 
     _onGetClientReady: function(result, e) {
         if (e) {
-            log ("Failed to connect to GeoClue2 service: " + e.message);
-            this._world.currentLocationChanged(null);
+            this._geoLocationFailed(e);
             return;
         }
 
@@ -124,12 +133,11 @@ const CurrentLocationController = new Lang.Class({
         let geoclueLocation = new LocationProxy(Gio.DBus.system,
                                                 "org.freedesktop.GeoClue2",
                                                 newPath);
-        let location = new Geocode.Location({ latitude: geoclueLocation.Latitude,
-                                              longitude: geoclueLocation.Longitude,
-                                              accuracy: geoclueLocation.Accuracy,
-                                              description: geoclueLocation.Description });
 
-        this.currentLocation = GWeather.Location.get_world().find_nearest_city (location.latitude, location.longitude);
+        this.currentLocation = GWeather.Location.new_detached(geoclueLocation.Description,
+                                                              null,
+                                                              geoclueLocation.Latitude,
+                                                              geoclueLocation.Longitude);
         this._world.currentLocationChanged(this.currentLocation);
     },
 
